Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(567)

Unified Diff: chrome/browser/ui/simple_message_box.h

Issue 2107493002: Offer user to send feedback from profile error dialog (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Unused variable Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/simple_message_box.h
diff --git a/chrome/browser/ui/simple_message_box.h b/chrome/browser/ui/simple_message_box.h
index d6f57db1e16a07803ea2eb399ef03d27dc9ea622..b64fcbad3dabc42f4410a9c2c9a125c93e640dda 100644
--- a/chrome/browser/ui/simple_message_box.h
+++ b/chrome/browser/ui/simple_message_box.h
@@ -11,8 +11,14 @@
namespace chrome {
enum MessageBoxResult {
- MESSAGE_BOX_RESULT_NO = 0, // User chose NO or CANCEL.
- MESSAGE_BOX_RESULT_YES = 1, // User chose YES or OK.
+ MESSAGE_BOX_RESULT_NO = 0, // User chose NO or CANCEL.
+ MESSAGE_BOX_RESULT_YES = 1, // User chose YES or OK.
+
+ // User chose YES or OK and the checkbox was checked.
+ MESSAGE_BOX_RESULT_YES_CHECKED = 2,
+
+ // User chose YES or OK and the checkbox was unchecked.
+ MESSAGE_BOX_RESULT_YES_NOTCHECKED = 3,
};
enum MessageBoxType {
@@ -31,6 +37,13 @@ void ShowWarningMessageBox(gfx::NativeWindow parent,
const base::string16& title,
const base::string16& message);
+// As above, but with a checkbox. Returns true if the checkbox was checked when
+// the dialog was dismissed, false otherwise.
+bool ShowWarningMessageBoxWithCheckbox(gfx::NativeWindow parent,
+ const base::string16& title,
+ const base::string16& message,
+ const base::string16& checkbox_text);
+
// As above, but two buttons are displayed and the return value indicates which
// is chosen.
MessageBoxResult ShowQuestionMessageBox(gfx::NativeWindow parent,

Powered by Google App Engine
This is Rietveld 408576698